@@ -1,8 +1,7 @@
-# encoding: utf-8
 # author: Dominik Richter
 # author: Christoph Hartmann
 
-require "base64"
+require "base64" unless defined?(Base64)
 require_relative "../errors"
 
 module Train::Extras
@@ -82,6 +81,9 @@ module Train::Extras
       when /sudo: sorry, you must have a tty to run sudo/
         ["Sudo requires a TTY. Please see the README on how to configure "\
           "sudo to allow for non-interactive usage.", :sudo_no_tty]
+      when /sudo: a terminal is required to read the password; either use/
+        ["Sudo cannot prompt for password because there is no terminal. "\
+            "Please provide the sudo password directly", :sudo_missing_terminal]
       else
         [rawerr, nil]
       end
