@@ -1,8 +1,7 @@
-# encoding: utf-8
 require "train/plugins"
 require "open3"
-require "ostruct"
-require "json"
+require "ostruct" unless defined?(OpenStruct)
+require "json" unless defined?(JSON)
 require "mkmf"
 
 module Train::Transports
@@ -17,7 +16,7 @@ module Train::Transports
       @connection ||= Connection.new(@options)
     end
 
-    class Connection < BaseConnection # rubocop:disable ClassLength
+    class Connection < BaseConnection # rubocop:disable Metrics/ClassLength
       POWERSHELL_PROMPT_REGEX = /PS\s.*> $/.freeze
 
       def initialize(options)
@@ -35,7 +34,7 @@ module Train::Transports
         @powershell_binary = detect_powershell_binary
 
         if @powershell_binary == :powershell
-          require_relative "local"
+          require "train/transports/local"
           @powershell = Train::Transports::Local::Connection.new(options)
         end
 
@@ -99,10 +98,11 @@ module Train::Transports
       private
 
       def detect_powershell_binary
-        if find_executable0("pwsh")
-          :pwsh
-        elsif find_executable0("powershell")
+        # Detect Powershell first in case of Windows with Powershell 6/7/Core installed as flush_stdout/stderr doesn't work for pwsh on Windows.
+        if find_executable0("powershell")
           :powershell
+        elsif find_executable0("pwsh")
+          :pwsh
         else
           raise "Cannot find PowerShell binary, is `pwsh` installed?"
         end
