@@ -1,11 +1,10 @@
-# encoding: utf-8
 # author: Dominik Richter
 # author: Christoph Hartmann
 #
 # Helper recipe to create create a few files in the operating
 # systems, which the runner will test against.
 
-gid = node["platform_family"] == "aix" ? "system" : node["root_group"]
+gid = platform_family?("aix") ? "system" : node["root_group"]
 
 file "/tmp/file" do
   mode "0765"
