@@ -1,4 +1,3 @@
-# encoding: utf-8
 require_relative "docker_run"
 tests = ARGV
 
@@ -6,7 +5,7 @@ def test_container(container, tests)
   puts "--> run test on docker #{container.id}"
   pid = Process.fork do
     ENV["CONTAINER"] = container.id
-    require_relative "docker_test_container.rb"
+    require_relative "docker_test_container"
     Process.exit
   end
 
